package dev.struchkov.yookassa.sdk.model.common;

import com.fasterxml.jackson.annotation.JsonProperty;
import dev.struchkov.yookassa.sdk.model.Required;
import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@Builder
@NoArgsConstructor
@AllArgsConstructor(access = AccessLevel.PRIVATE)
public class Item {

    /**
     * Название товара (не более 128 символов). Тег в 54 ФЗ — 1030.
     */
    @Required
    private String description;

    /**
     * Цена товара (тег в 54 ФЗ — 1079).
     */
    @Required
    private Amount amount;

    /**
     * Ставка НДС (тег в 54 ФЗ — 1199).
     * Для чеков по 54-ФЗ: возможные значения — числа от 1 до 6. Подробнее про коды ставок НДС
     * Для чеков самозанятых: фиксированное значение — 1.
     */
    @Required
    @JsonProperty("vat_code")
    private Integer vatCode;

    /**
     * Количество товара (тег в 54 ФЗ — 1023).
     * Для чеков по 54-ФЗ: максимально возможное значение зависит от модели вашей онлайн-кассы.
     * Для чеков самозанятых: только целые положительные числа (без разделителя и дробной части). Пример: 1.
     */
    @Required
    private String quantity;

    /**
     * Мера количества предмета расчета (тег в 54 ФЗ — 2108) — единица измерения товара, например штуки, граммы. Обязателен при использовании ФФД 1.2. <a href="https://yookassa.ru/developers/payment-acceptance/scenario-extensions/receipts/54fz/parameters-values#measure">Перечень возможных значений</a>
     */
    private String measure;

    /**
     * Дробное количество маркированного товара (тег в 54 ФЗ — 1291). Нужно передавать при одновременном выполнении следующих условий:
     * используется ФФД версии 1.2;
     * расчет осуществляется за маркированный товар;
     * поле measure имеет значение piece.
     * Пример: вы продаете поштучно карандаши. Они поставляются пачками по 100 штук с одним кодом маркировки. При продаже одного карандаша нужно в numerator передать 1, а в denominator — 100.
     */
    @JsonProperty("mark_quantity")
    private MarkQuantity markQuantity;

    /**
     * Признак предмета расчета (тег в 54 ФЗ — 1212) — это то, за что принимается оплата, например товар, услуга. <a href="https://yookassa.ru/developers/payment-acceptance/scenario-extensions/receipts/54fz/parameters-values#payment-subject">Перечень возможных значений </a>
     */
    @JsonProperty("payment_subject")
    private String paymentSubject;

    /**
     * Признак способа расчета (тег в 54 ФЗ — 1214) — отражает тип оплаты и факт передачи товара. Пример: покупатель полностью оплачивает товар и сразу получает его. В этом случае нужно передать значение full_payment (полный расчет). <a href="https://yookassa.ru/developers/payment-acceptance/scenario-extensions/receipts/54fz/parameters-values#payment-mode">Перечень возможных значений</a>
     */
    @JsonProperty("payment_mode")
    private String paymentMode;

    /**
     * Код страны происхождения товара по общероссийскому классификатору стран мира (OК (MК (ИСО 3166) 004-97) 025-2001). Тег в 54 ФЗ — 1230. Пример: RU.
     * Онлайн-кассы, которые поддерживают этот параметр: Orange Data, Кит Инвест.
     */
    @JsonProperty("country_of_origin_code")
    private String countryOfOriginCode;

    /**
     * Номер таможенной декларации (от 1 до 32 символов). Тег в 54 ФЗ — 1231.
     * Онлайн-кассы, которые поддерживают этот параметр: Orange Data, Кит Инвест.
     */
    @JsonProperty("customs_declaration_number")
    private String customsDeclarationNumber;

    /**
     * Сумма акциза товара с учетом копеек (тег в 54 ФЗ — 1229). Десятичное число с точностью до 2 символов после точки.
     * Онлайн-кассы, которые поддерживают этот параметр: Orange Data, Кит Инвест.
     */
    private String excise;

    /**
     * Код товара (тег в 54 ФЗ — 1162) — уникальный номер, который присваивается экземпляру товара при маркировке.
     * Формат: число в шестнадцатеричном представлении с пробелами. Максимальная длина — 32 байта. Пример: 00 00 00 01 00 21 FA 41 00 23 05 41 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 12 00 AB 00.
     * Обязательный параметр, если вы используете ФФД 1.05 и товар нужно маркировать.
     */
    private String productCode;
}
